summaryrefslogtreecommitdiffstats
path: root/nsplugins/viewer/qxteventloop.h
diff options
context:
space:
mode:
Diffstat (limited to 'nsplugins/viewer/qxteventloop.h')
-rw-r--r--nsplugins/viewer/qxteventloop.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/nsplugins/viewer/qxteventloop.h b/nsplugins/viewer/qxteventloop.h
index 0bed590b2..02ed69541 100644
--- a/nsplugins/viewer/qxteventloop.h
+++ b/nsplugins/viewer/qxteventloop.h
@@ -1,6 +1,6 @@
/****************************************************************************
**
** Implementation of QWidget class
**
** Created : 931031
**
@@ -36,10 +36,10 @@
#ifndef QXTEVENTLOOP_H
#define QXTEVENTLOOP_H
-#include <qglobal.h>
+#include <tqglobal.h>
#if QT_VERSION >= 0x030100
-#include <qeventloop.h>
+#include <tqeventloop.h>
@@ -57,11 +57,11 @@ public:
XtAppContext applicationContext() const;
- void registerSocketNotifier( QSocketNotifier * );
- void unregisterSocketNotifier( QSocketNotifier * );
+ void registerSocketNotifier( TQSocketNotifier * );
+ void unregisterSocketNotifier( TQSocketNotifier * );
- static void registerWidget( QWidget* );
- static void unregisterWidget( QWidget* );
+ static void registerWidget( TQWidget* );
+ static void unregisterWidget( TQWidget* );
static bool redeliverEvent( XEvent *event );
static XEvent* lastEvent();
@@ -1,6 +1,6 @@
/****************************************************************************
**
-** Implementation of QWidget class
+** Implementation of TQWidget class
**
** Created : 931031